//Создание задачи диспетчерского вызова прочих задач
function [ProjectName,..//Имя проекта
          err,msg]=CreateSystemFormalModelingProject(DisplayFunction,..//Функция отправки сообщения
                                                     TaskReadFunction,..//Функция получения сообщения задачами
                                                     TaskDisplayFunction,..//Функция отправки сообщения от задач
                                                     ProjectDirectory,..//Имя директории проекта
                                                     errPrintMsg..//Печатаем или нет сообщения об ошибках
                                                     )
    //Анализируем аргументы
    nArg = argn(2);
    if nArg < 3 then
        error('the function CreateSystemFormalModelingProject takes 3, 4, or 5 arguments');
    end
    select nArg
    case 3 then
        ProjectDirectory = pwd();
        errPrintMsg = %t;//По умолчанию печатаем сообщения об ошибках
    case 4 then
        if type(ProjectDirectory) == 4 then
            errPrintMsg = ProjectDirectory;
            ProjectDirectory = pwd();
        else
            errPrintMsg = %t;//По умолчанию печатаем сообщения об ошибках
        end
    end
    
    //Считываем файл проекта
    [ProjectName,DatasTasks,..
     RandomGenerateParametrsTasks,..
     ComputingExperimentTasks,..
     SystemDynamicCountPropertiesTasks,..
     SystemCharacteristicsCountPropertiesTasks,..
     SystemValuesConcatenateTasks,..
     FunctionsLibs,TasksDependenciesTableFileName,..
     EnabledTaskDatasNames]=fileProjectReading(ProjectDirectory);
    
    //Сохраняем на диск функции чтения и отображения
    if isempty(ReadFunction) then
        ReadFunction = list('input','s');
    end
    if isempty(DisplayFunction) then
        DisplayFunction = 'disp';
    end
    PerFile(TaskReadFunction,'ReadFunction');
    PerFile(TaskDisplayFunction,'DisplayFunction');
    
    //Создаем проект
    [err,msg]=AddProjects(ProjectName,errPrintMsg);
    if err ~= 0 then
        return;
    end
    
    //Отображаем имя проекта
    DispProjectName(DisplayFunction,ProjectName);
    
    //Добавляем файлы данных в проект
    [err,msg]=AddDatasTasks(DatasTasks,ProjectName,..
                            ProjectDirectory,..
                            errPrintMsg);
    if err ~= 0 then
        return;
    end
    
    //Добавляем файлы задач генерации случайных значений параметров
    [err,msg]=CreateRandomGenereteSystemParametrsTasks(RandomGenerateParametrsTasks,..
                                                       ProjectName,..
                                                       ProjectDirectory,..
                                                       errPrintMsg);
    if err ~= 0 then
        return;
    end
    
    //Добавляем файлы задач безитерационного моделирования
    [err,msg]=CreateComputingExperimentSystemTasks(ComputingExperimentTasks,..
                                                   ProjectName,..
                                                   ProjectDirectory,..
                                                   errPrintMsg);
    if err ~= 0 then
        return;
    end
    
    //Добавляем файлы задач фильтрации динамик
    [err,msg]=CreateSystemDynamicCountPropertiesTasks(SystemDynamicCountPropertiesTasks,..
                                                      ProjectName,..
                                                      ProjectDirectory,..
                                                      errPrintMsg);
    if err ~= 0 then
        return;
    end
    
    //Добавляем файлы задач фильтрации динамик
    [err,msg]=CreateCountSystemCharacteristicsPropertiesTasks(SystemCharacteristicsCountPropertiesTasks,..
                                                              ProjectName,..
                                                              ProjectDirectory,..
                                                              errPrintMsg);
    if err ~= 0 then
        return;
    end
    
    //Добавляем файлы задач конкатенации динамик и характеристик системы
    [err,msg]=CreateSystemValuesConcatenateTasks(SystemValuesConcatenateTasks,..
                                                 ProjectName,..
                                                 ProjectDirectory,..
                                                 errPrintMsg);
    if err ~= 0 then
        return;
    end
    
    //Добавляем библиотеки функций состояния
    [err,msg]=AddFunctionsLibs(FunctionsLibs,ProjectName,..
                               fullfile(ProjectDirectory,..
                                        FunctionsLibs),errPrintMsg);
    if err ~= 0 then
        return;
    end
    
    //Добавляем зависимости задач
    AllTasksNames = [RandomGenerateParametrsTasks,..
                     ComputingExperimentTasks,..
                     SystemDynamicCountPropertiesTasks,..
                     SystemCharacteristicsCountPropertiesTasks,..
                     SystemValuesConcatenateTasks];//Все задачи из проекта
    TasksDependenciesTableFileName = fullfile(ProjectDirectory,TasksDependenciesTableFileName);
    [err,msg]=AddDependenciesTasks(AllTasksNames,..//Имена задач
                                   TasksDependenciesTableFileName,..//Имя файла таблицы зависимостей задач
                                   EnabledTaskDatasNames,..//Имена доступных данных
                                   ProjectName,errPrintMsg);
    if err ~= 0 then
        return;
    end
endfunction

//Функция считывания файла проекта
function [ProjectName,..
          DatasTasks,..
          RandomGenerateParametrsTasks,..
          ComputingExperimentTasks,..
          SystemDynamicCountPropertiesTasks,..
          SystemCharacteristicsCountPropertiesTasks,..
          SystemValuesConcatenateTasks,..
          FunctionsLibs,..
          TasksDependenciesTableFileName,..
          EnabledTaskDatasNames]=fileProjectReading(ProjectDirectory)
    //Переходим в директорию проекта
    curScilabDir = pwd();//Текущая директория Scilab
    chdir(ProjectDirectory);//Переходим в директорию проекта
    
    //Ищем файл подпроекта аугментации данных
    ProjectFileName = findfiles(ProjectDirectory,'*.proj');//Получаем имя файла подпроекта аугментации данных
    ProjectFileName = fullfile(ProjectDirectory, ProjectFileName);//Полное имя файла подпроекта аугментации данных
    
    //Считываем и выполняем файл проекта
    strsProjectConfigurations = mgetl(ProjectFileName);//Получаем конфигурацию проекта в виде строк
    if errPrintMsg then
        err = execstr(strsProjectConfigurations,'errcatch','m');
    else
        err = execstr(strsProjectConfigurations,'errcatch','n');
    end
    if err ~= 0 then
        msg = lasterror();//Выводим сообщение об ошибке
    end
    
    //Возвращаемся в исходную директорию Scilab
    chdir(curScilabDir);
endfunction

//Функция формирования файла функций записи и считывания
function PerFile(Function,FunctionName)
    //Формируем полное имя файла шаблона задачи
    fullFileName = fullfile(SCIHOME,'administrate_formal_modeling_system_dynamic_project_templates',FunctionName + '.sce');
    
    //Пишем имя функции в файл шаблона задач
    select type(Function)
    case 10 then
        if size(Function,'*') > 1 then
            return;
        end
        _Function = '""' + Function + '""';
    case 15 then
        _Function = 'list(' + Function(1);
        for fFunction=Function(2:$)
            if type(fFunction) == 10 then
                _Function = _Function + ',""' + fFunction + '""';
            else
                _Function = _Function + ',' + string(fFunction);
            end
        end
        _Function = _Function + ')';
    else
        return;
    end
    mputl(FunctionName + ' = ' + _Function + ';', fullFileName);
endfunction

//Отображаем имя проекта
function DispProjectName(DisplayFunction,ProjectName)
    //Формируем функцию вывода
    select type(DisplayFunction)
    case 10 then
        execstr('displayFunction = ' + DisplayFunction);
    case 15 then
        //Получаем имя функции отображения и ее параметры
        dFunction = DisplayFunction(1);
        dFunctionParametrs = DisplayFunction(2:$);
        
        //Приводим имя функции к типу функции
        execstr('dFunction = ' + dFunction);
        
        //Формируем функцию вызова
        function displayFunction(dispStr)
            dFunction(dispStr,dFunctionParametrs(:));
        endfunction
    end
    
    //Выводим имя проекта
    displayFunction('Name of project: ' + ProjectName);
endfunction
