//Создание задачи диспетчерского вызова прочих задач
function [err,msg]=CreateTasksForAugmentation(ArgumentsFilesNames,..//Имена файлов аргументов
                                              TasksTemplatesNames,..//Имена шаблонов задач
                                              ProjectName,..//Имя проекта
                                              ProjectDirectory,..//Имя директории проекта
                                              errPrintMsg..//Печатаем или нет сообщения об ошибках
                                              )
    //Проверяем аргументы
    nArg = argn(2);//Число аргументов
    if nArg < 2 then
        error('The function CreateTasksForAugmentation takes 2, 3, 4, 5 or 6 arguments');
    end
    select nArg
    case 2 then
        copyTemplatesNames = %f;
        ProjectName = '';
        ProjectDirectory = pwd();
        errPrintMsg = %t;//По умолчанию печатаем сообщения об ошибках
    case 3 then
        ProjectName = '';
        ProjectDirectory = pwd();
        errPrintMsg = %t;//По умолчанию печатаем сообщения об ошибках
    case 4 then
        if type(ProjectName) == 4 then
            errPrintMsg = ProjectName;
            ProjectName = '';
        else
            errPrintMsg = %t;//По умолчанию печатаем сообщения об ошибках
        end
        ProjectDirectory = pwd();
    case 5 then
        if type(ProjectDirectory) == 4 then
            errPrintMsg = ProjectDirectory;
            ProjectDirectory = pwd();
        else
            errPrintMsg = %t;//По умолчанию печатаем сообщения об ошибках
        end
    end
    
    //Проверяем, является ли файл аргументов пустым
    if isempty(ArgumentsFilesNames) then
        err = 0;
        msg = "";
        
        //Выходим из программы
        return;
    end
    
    //Проверяем корректность аргументов
    if type(ArgumentsFilesNames) ~= 10 then
        error('The argument ArgumentsFilesNames of function CreateTasksForAugmentation must be matrix of string');
    end
    if type(TasksTemplatesNames) ~= 10 then
        error('The argument TasksTemplatesNames of function CreateTasksForAugmentation must be matrix of string');
    end
    if (type(ProjectName) ~= 10) ||..
       (size(ProjectName,'*') ~= 1) then
        error('The argument ProjectName of function CreateTasksForAugmentation must be scalar string');
    end
    if (type(ProjectDirectory) ~= 10) ||..
       (size(ProjectDirectory,'*') ~= 1) then
        error('The argument ProjectDirectory of function CreateTasksForAugmentation must be scalar string');
    end
    if (type(errPrintMsg) ~= 4) ||..
       (size(errPrintMsg,'*') ~= 1) then
        error('The argument errPrintMsg of function CreateTasksForAugmentation must be scalar boolean');
    end
    
    //Формируем полные имена
    ProjectTasksDirectory = fullfile(ProjectDirectory,'ProjectTasks');//Полное имя директории файлов задач
    fullArgumentsFilesNames = fullfile(ProjectDirectory,ArgumentsFilesNames);//Полные имена файлов аргументов
    DirectoryTemplateTasks = fullfile(SCIHOME,'administrate_formal_modeling_system_dynamic_project_templates');//Директория опорных задач
    
    //Формируем задачи
    [err,msg]=CreateTasksByTemplateTasks(fullArgumentsFilesNames,..//Полные имена файлов аргументов
                                         ProjectTasksDirectory,..//Полное имя директории файлов сгенерированных задач
                                         TasksTemplatesNames,..//Опорные шаблонные задачи
                                         ProjectName,..//Имя проекта
                                         "ProjectName",..//Написание в коде переменной имени проекта
                                         DirectoryTemplateTasks,..//Директории опорных шаблонных задач
                                         %t,..//Текст шаблонных файлов задач копируем, а добавляем ссылку
                                         %t,..//Директорию задач удаляем
                                         errPrintMsg..//Печатаем или нет сообщения об ошибках
                                         );
endfunction
